@@ -19,9 +19,9 @@
     useful for tools such as debuggers.
 """
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  Imports:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
 import wx
 import wx.stc as stc
@@ -50,9 +50,9 @@ from .editor \
 from .constants \
     import OKColor, ErrorColor
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  Constants:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
 # Marker line constants:
 
@@ -65,23 +65,24 @@ SEARCH_MARKER = 1
 # Marks the currently selected line
 SELECTED_MARKER = 2
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  'SourceEditor' class:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
-class SourceEditor ( Editor ):
+
+class SourceEditor(Editor):
     """ Editor for source code, which displays a PyFace PythonEditor.
     """
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Trait definitions:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
     # The code editor is scrollable. This value overrides the default.
     scrollable = True
 
     # Is the editor read only?
-    readonly = Bool( False )
+    readonly = Bool(False)
 
     # The currently selected line
     selected_line = Int
@@ -90,7 +91,7 @@ class SourceEditor ( Editor ):
     selected_text = Str
 
     # The list of line numbers to mark
-    mark_lines = List( Int )
+    mark_lines = List(Int)
 
     # The current line number
     line = Event
@@ -107,24 +108,24 @@ class SourceEditor ( Editor ):
     # The lines to be dimmed
     dim_lines = List(Int)
     dim_color = Str
-    _dim_style_number = Int(16) # 0-15 are reserved for the python lexer
+    _dim_style_number = Int(16)  # 0-15 are reserved for the python lexer
 
     # The lines to have squiggles drawn under them
     squiggle_lines = List(Int)
     squiggle_color = Str
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Finishes initializing the editor by creating the underlying toolkit
     #  widget:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def init ( self, parent ):
+    def init(self, parent):
         """ Finishes initializing the editor by creating the underlying toolkit
             widget.
         """
-        factory      = self.factory
-        self._editor = editor  = PythonEditor( parent,
-                                 show_line_numbers = factory.show_line_numbers )
+        factory = self.factory
+        self._editor = editor = PythonEditor(
+            parent, show_line_numbers=factory.show_line_numbers)
         self.control = control = editor.control
 
         # There are a number of events which aren't well documented that look
@@ -136,30 +137,30 @@ class SourceEditor ( Editor ):
         #    EVT_STC_DOUBLECLICK
         #    EVT_STC_MARGINCLICK
 
-        control.SetSize( wx.Size( 300, 124 ) )
+        control.SetSize(wx.Size(300, 124))
 
         # Clear out the goofy hotkeys for zooming text
         control.CmdKeyClear(ord('B'), stc.STC_SCMOD_CTRL)
         control.CmdKeyClear(ord('N'), stc.STC_SCMOD_CTRL)
 
         # Set up the events
-        wx.EVT_KILL_FOCUS( control, self.wx_update_object )
-        stc.EVT_STC_CALLTIP_CLICK( control, control.GetId(),
-                                   self._calltip_clicked )
+        wx.EVT_KILL_FOCUS(control, self.wx_update_object)
+        stc.EVT_STC_CALLTIP_CLICK(control, control.GetId(),
+                                  self._calltip_clicked)
 
         if factory.auto_scroll and (factory.selected_line != ''):
-            wx.EVT_SIZE( control, self._update_selected_line )
+            wx.EVT_SIZE(control, self._update_selected_line)
 
         if factory.auto_set:
-            editor.on_trait_change( self.update_object, 'changed',
-                                    dispatch = 'ui' )
+            editor.on_trait_change(self.update_object, 'changed',
+                                   dispatch='ui')
 
         if factory.key_bindings is not None:
-            editor.on_trait_change( self.key_pressed, 'key_pressed',
-                                    dispatch = 'ui' )
+            editor.on_trait_change(self.key_pressed, 'key_pressed',
+                                   dispatch='ui')
 
         if self.readonly:
-            control.SetReadOnly( True )
+            control.SetReadOnly(True)
 
         # Set up the lexer
         control.SetLexer(stc.STC_LEX_CONTAINER)
@@ -170,24 +171,24 @@ class SourceEditor ( Editor ):
             self.lexer = stc.STC_LEX_NULL
 
         # Define the markers we use:
-        control.MarkerDefine( MARK_MARKER, stc.STC_MARK_BACKGROUND,
-                              background = factory.mark_color_ )
-        control.MarkerDefine( SEARCH_MARKER, stc.STC_MARK_BACKGROUND,
-                              background = factory.search_color_ )
-        control.MarkerDefine( SELECTED_MARKER, stc.STC_MARK_BACKGROUND,
-                              background = factory.selected_color_ )
+        control.MarkerDefine(MARK_MARKER, stc.STC_MARK_BACKGROUND,
+                             background=factory.mark_color_)
+        control.MarkerDefine(SEARCH_MARKER, stc.STC_MARK_BACKGROUND,
+                             background=factory.search_color_)
+        control.MarkerDefine(SELECTED_MARKER, stc.STC_MARK_BACKGROUND,
+                             background=factory.selected_color_)
 
         # Make sure the editor has been initialized:
         self.update_editor()
 
         # Set up any event listeners:
-        self.sync_value( factory.mark_lines, 'mark_lines', 'from',
-                         is_list = True )
-        self.sync_value( factory.selected_line, 'selected_line', 'from' )
-        self.sync_value( factory.selected_text, 'selected_text', 'to' )
-        self.sync_value( factory.line, 'line' )
-        self.sync_value( factory.column, 'column' )
-        self.sync_value( factory.calltip_clicked, 'calltip_clicked')
+        self.sync_value(factory.mark_lines, 'mark_lines', 'from',
+                        is_list=True)
+        self.sync_value(factory.selected_line, 'selected_line', 'from')
+        self.sync_value(factory.selected_text, 'selected_text', 'to')
+        self.sync_value(factory.line, 'line')
+        self.sync_value(factory.column, 'column')
+        self.sync_value(factory.calltip_clicked, 'calltip_clicked')
 
         self.sync_value(factory.dim_lines, 'dim_lines', 'from', is_list=True)
         if self.factory.dim_color == '':
@@ -202,158 +203,159 @@ class SourceEditor ( Editor ):
         else:
             self.sync_value(factory.squiggle_color, 'squiggle_color', 'from')
 
-        # Check if we need to monitor the line or column position being changed:
+        # Check if we need to monitor the line or column position being
+        # changed:
         if (factory.line != '') or (factory.column != '') or \
                 (factory.selected_text != ''):
-            stc.EVT_STC_UPDATEUI( control, control.GetId(),
-                                  self._position_changed )
+            stc.EVT_STC_UPDATEUI(control, control.GetId(),
+                                 self._position_changed)
         self.set_tooltip()
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Handles the user entering input data in the edit control:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def wx_update_object ( self, event ):
+    def wx_update_object(self, event):
         """ Handles the user entering input data in the edit control.
         """
         self.update_object()
         event.Skip()
 
-    def update_object ( self ):
+    def update_object(self):
         """ Handles the user entering input data in the edit control.
         """
         if not self._locked:
             try:
                 value = self.control.GetText()
-                if isinstance( self.value, SequenceTypes ):
+                if isinstance(self.value, SequenceTypes):
                     value = value.split()
                 self.value = value
-                self.control.SetBackgroundColour( OKColor )
+                self.control.SetBackgroundColour(OKColor)
                 self.control.Refresh()
             except TraitError as excp:
                 pass
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Updates the editor when the object trait changes external to the editor:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def update_editor ( self ):
+    def update_editor(self):
         """ Updates the editor when the object trait changes externally to the
             editor.
         """
         self._locked = True
-        new_value    = self.value
-        if isinstance( new_value, SequenceTypes ):
-            new_value = '\n'.join( [ line.rstrip() for line in new_value ] )
+        new_value = self.value
+        if isinstance(new_value, SequenceTypes):
+            new_value = '\n'.join([line.rstrip() for line in new_value])
         control = self.control
         if control.GetText() != new_value:
             readonly = control.GetReadOnly()
-            control.SetReadOnly( False )
-            l1  = control.GetFirstVisibleLine()
+            control.SetReadOnly(False)
+            l1 = control.GetFirstVisibleLine()
             pos = control.GetCurrentPos()
-            control.SetText( new_value )
-            control.GotoPos( pos )
-            control.ScrollToLine( l1 )
-            control.SetReadOnly( readonly )
+            control.SetText(new_value)
+            control.GotoPos(pos)
+            control.ScrollToLine(l1)
+            control.SetReadOnly(readonly)
             self._mark_lines_changed()
             self._selected_line_changed()
             self._style_document()
 
         self._locked = False
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Handles the calltip being clicked:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def _calltip_clicked ( self, event ):
+    def _calltip_clicked(self, event):
         self.calltip_clicked = True
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Handles the set of 'marked lines' being changed:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def _mark_lines_changed ( self ):
+    def _mark_lines_changed(self):
         """ Handles the set of marked lines being changed.
         """
-        lines   = self.mark_lines
+        lines = self.mark_lines
         control = self.control
-        lc      = control.GetLineCount()
-        control.MarkerDeleteAll( MARK_MARKER )
+        lc = control.GetLineCount()
+        control.MarkerDeleteAll(MARK_MARKER)
 
         for line in lines:
             if 0 < line <= lc:
-                control.MarkerAdd( line - 1, MARK_MARKER )
+                control.MarkerAdd(line - 1, MARK_MARKER)
 
         control.Refresh()
 
-    def _mark_lines_items_changed ( self ):
+    def _mark_lines_items_changed(self):
         self._mark_lines_changed()
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Handles the currently 'selected line' being changed:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def _selected_line_changed ( self ):
+    def _selected_line_changed(self):
         """ Handles a change in which line is currently selected.
         """
-        line    = self.selected_line
+        line = self.selected_line
         control = self.control
-        line    = max( 1, min( control.GetLineCount(), line ) ) - 1
-        control.MarkerDeleteAll( SELECTED_MARKER )
-        control.MarkerAdd( line, SELECTED_MARKER )
-        control.GotoLine( line )
+        line = max(1, min(control.GetLineCount(), line)) - 1
+        control.MarkerDeleteAll(SELECTED_MARKER)
+        control.MarkerAdd(line, SELECTED_MARKER)
+        control.GotoLine(line)
         if self.factory.auto_scroll:
-            control.ScrollToLine( line - (control.LinesOnScreen() / 2) )
+            control.ScrollToLine(line - (control.LinesOnScreen() / 2))
 
         control.Refresh()
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Handles the 'line' trait being changed:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def _line_changed ( self, line ):
+    def _line_changed(self, line):
         if not self._locked:
-            self.control.GotoLine( line - 1 )
+            self.control.GotoLine(line - 1)
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Handles the 'column' trait being changed:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def _column_changed ( self, column ):
+    def _column_changed(self, column):
         if not self._locked:
             control = self.control
-            line    = control.LineFromPosition( control.GetCurrentPos() )
-            control.GotoPos( control.PositionFromLine( line ) + column - 1 )
+            line = control.LineFromPosition(control.GetCurrentPos())
+            control.GotoPos(control.PositionFromLine(line) + column - 1)
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Handles the cursor position being changed:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def _position_changed ( self, event ):
+    def _position_changed(self, event):
         """ Handles the cursor position being changed.
         """
-        control      = self.control
-        pos          = control.GetCurrentPos()
-        line         = control.LineFromPosition( pos )
+        control = self.control
+        pos = control.GetCurrentPos()
+        line = control.LineFromPosition(pos)
         self._locked = True
-        self.line    = line + 1
-        self.column  = pos - control.PositionFromLine( line ) + 1
+        self.line = line + 1
+        self.column = pos - control.PositionFromLine(line) + 1
         self._locked = False
         self.selected_text = control.GetSelectedText()
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Handles a key being pressed within the editor:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def key_pressed ( self, event ):
+    def key_pressed(self, event):
         """ Handles a key being pressed within the editor.
         """
-        self.factory.key_bindings.do( event.event, self.ui.handler,
-                                      self.ui.info )
+        self.factory.key_bindings.do(event.event, self.ui.handler,
+                                     self.ui.info)
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Handles the styling of the editor:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
     def _dim_color_changed(self):
         self.control.StyleSetForeground(self._dim_style_number, self.dim_color)
@@ -389,19 +391,20 @@ class SourceEditor ( Editor ):
             start_line -= 1
 
         # Trying to Colourise only the lines that we want does not seem to work
-        # so we do the whole area and then override the styling on certain lines
+        # so we do the whole area and then override the styling on certain
+        # lines
         if self.lexer != stc.STC_LEX_NULL:
             self.control.SetLexer(self.lexer)
             self.control.Colourise(position, end)
             self.control.SetLexer(stc.STC_LEX_CONTAINER)
 
-        for line in range(start_line, end_line+1):
+        for line in range(start_line, end_line + 1):
             # We don't use LineLength here because it includes newline
             # characters. Styling these leads to strange behavior.
             position = self.control.PositionFromLine(line)
             style_length = self.control.GetLineEndPosition(line) - position
 
-            if line+1 in self.dim_lines:
+            if line + 1 in self.dim_lines:
                 # Set styling mask to only style text bits, not indicator bits
                 self.control.StartStyling(position, 0x1f)
                 self.control.SetStyling(style_length, self._dim_style_number)
@@ -409,74 +412,75 @@ class SourceEditor ( Editor ):
                 self.control.StartStyling(position, 0x1f)
                 self.control.SetStyling(style_length, stc.STC_STYLE_DEFAULT)
 
-            if line+1 in self.squiggle_lines:
+            if line + 1 in self.squiggle_lines:
                 self.control.StartStyling(position, stc.STC_INDIC2_MASK)
                 self.control.SetStyling(style_length, stc.STC_INDIC2_MASK)
             else:
                 self.control.StartStyling(position, stc.STC_INDIC2_MASK)
                 self.control.SetStyling(style_length, stc.STC_STYLE_DEFAULT)
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Handles an error that occurs while setting the object's trait value:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def error ( self, excp ):
+    def error(self, excp):
         """ Handles an error that occurs while setting the object's trait value.
         """
-        self.control.SetBackgroundColour( ErrorColor )
+        self.control.SetBackgroundColour(ErrorColor)
         self.control.Refresh()
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Disposes of the contents of an editor:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def dispose ( self ):
+    def dispose(self):
         """ Disposes of the contents of an editor.
         """
         if self.factory.auto_set:
-            self._editor.on_trait_change( self.update_object, 'changed',
-                                          remove = True )
+            self._editor.on_trait_change(self.update_object, 'changed',
+                                         remove=True)
         if self.factory.key_bindings is not None:
-            self._editor.on_trait_change( self.key_pressed, 'key_pressed',
-                                          remove = True )
+            self._editor.on_trait_change(self.key_pressed, 'key_pressed',
+                                         remove=True)
 
-        wx.EVT_KILL_FOCUS( self.control, None )
+        wx.EVT_KILL_FOCUS(self.control, None)
 
-        super( SourceEditor, self ).dispose()
+        super(SourceEditor, self).dispose()
 
-    #-- UI preference save/restore interface -----------------------------------
+    #-- UI preference save/restore interface ---------------------------------
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Restores any saved user preference information associated with the
     #  editor:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def restore_prefs ( self, prefs ):
+    def restore_prefs(self, prefs):
         """ Restores any saved user preference information associated with the
             editor.
         """
         if self.factory.key_bindings is not None:
-            key_bindings = prefs.get( 'key_bindings' )
+            key_bindings = prefs.get('key_bindings')
             if key_bindings is not None:
-                self.factory.key_bindings.merge( key_bindings )
+                self.factory.key_bindings.merge(key_bindings)
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Returns any user preference information associated with the editor:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def save_prefs ( self ):
+    def save_prefs(self):
         """ Returns any user preference information associated with the editor.
         """
-        return { 'key_bindings': self.factory.key_bindings }
+        return {'key_bindings': self.factory.key_bindings}
 
 # Define the simple, custom, text and readonly editors, which will be accessed
 # by the editor factory for code editors.
 
 CustomEditor = SimpleEditor = TextEditor = SourceEditor
 
+
 class ReadonlyEditor(SourceEditor):
 
     # Set the value of the readonly trait.
     readonly = True
 
-### EOF ########################################################################
+### EOF ##################################################################
